@@ -1,17 +1,17 @@
 ##############################################################################
 # Net::Twitter - Perl OO interface to www.twitter.com
-# v2.11
+# v2.12
 # Copyright (c) 2009 Chris Thompson
 ##############################################################################
 
 package Net::Twitter;
-$VERSION = "2.11";
+$VERSION = "2.12";
 use 5.005;
 use strict;
 
 use URI::Escape;
 use JSON::Any 1.19;
-use LWP::UserAgent;
+use LWP::UserAgent 2.032;
 use Carp;
 
 sub new {
@@ -810,7 +810,7 @@ Net::Twitter - Perl interface to twitter.com
 
 =head1 VERSION
 
-This document describes Net::Twitter version 2.11
+This document describes Net::Twitter version 2.12
 
 =head1 SYNOPSIS
 
