@@ -175,6 +175,17 @@ my %twitter_api = (
         "post"      => 1,
         "args"      => {},
     },
+    "/account/update_profile" => {
+        "blankargs" => 0,
+        "post"      => 1,
+        "args"      => {
+            "name"        => 0,
+            "email"       => 0,
+            "url"         => 0,
+            "location"    => 0,
+            "description" => 0,
+        },
+    },
     "/account/update_profile_colors" => {
         "blankargs" => 0,
         "post"      => 1,
